#
# spec file for package python-vega
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define         skip_python2 1
Name:           python-vega
Version:        2.6.0
Release:        bp155.2.11
Summary:        An IPython/Jupyter widget for Vega 3 and Vega-Lite 2
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            http://github.com/vega/ipyvega/
Source:         https://files.pythonhosted.org/packages/source/v/vega/vega-%{version}.tar.gz
BuildRequires:  %{python_module jupyter-client >= 4.2}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  jupyter-notebook-filesystem
BuildRequires:  python-rpm-macros
Requires:       jupyter-vega = %{version}
Requires:       python-ipython
Requires:       python-jupyter-client >= 4.2
Provides:       python-jupyter_vega = %{version}
Obsoletes:      python-jupyter_vega < %{version}
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module ipython}
BuildRequires:  %{python_module numpy}
BuildRequires:  %{python_module pandas}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
IPython/Jupyter notebook module for Vega and Vega-Lite,
Polestar, and Voyager. Notebooks with embedded visualizations
can be viewed on github and nbviewer.

This package provides the python interface.

%package     -n jupyter-vega
Summary:        An IPython/Jupyter widget for Vega 3 and Vega-Lite 2
Requires:       jupyter-notebook
Requires:       python3-vega = %{version}
Conflicts:      python3-jupyter_vega < 2.1.0

%description -n jupyter-vega
IPython/Jupyter notebook module for Vega and Vega-Lite,
Polestar, and Voyager. Notebooks with embedded visualizations
can be viewed on github and nbviewer.

This package provides the jupyter notebook extension.

%prep
%setup -q -n vega-%{version}
rm -rf vega/.ipynb_checkpoints

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

export PYTHONPATH=%{buildroot}%{python3_sitelib}
%{jupyter_move_config}

%{fdupes %{buildroot}%{_jupyter_prefix} %{buildroot}%{python3_sitelib}}

%check
%pytest vega

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/vega/
%{python_sitelib}/vega-%{version}-py*.egg-info

%files -n jupyter-vega
%license LICENSE
%{_jupyter_nbextension_dir}/jupyter-vega/
%config %{_jupyter_nb_notebook_confdir}/vega.json

%changelog
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.6.0
  * Update deps and rebuild
* Sun Aug 11 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.5.0
  * Update deps and rebuild
* Mon Jul 29 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.4.0
  * Update typings
  * Update dependencies in package.json as well
  * No need to set default style.
- Update to 2.3.1
  * Ad try catch around widget code
  * Update deps
* Wed Jun 12 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.3.0
  * Add implementation of ipython widget
  * Address review comments
  * Fix optional dependencies with webpack
  * Fix typescript style
  * Handle updates before widget is rendered correctly
  * Add lightweight error messaging for updates
  * Add description to notebook
  * Call finalize when replacing the view
  * Fix error in finalize call, rebuild static js
  * Remove from_chart and update docstring accordingly
  * Make TODO comment re validation more self-explanatory
  * Allow to set embedding options
  * Add point how to select between vega / vega-lite
  * remove defaultStyle
  * Ignore notebooks in package
  * Upgrade deps
- Update to 2.2.0
  * Don't set style since Embed has changed the default anyway
  * Upgrade deps
* Wed May 15 2019 Todd R <toddrme2178@gmail.com>
- Add conflicts to jupyter subpackage to more explicitly handle
  file overlaps with old naming scheme.
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Update to 2.1.0
  * Rebuild bundles
  * Upgrade dependencies
  * Use prettier check
  * Update Vega-Embed
- Rename to to match python package naming guidelines.
- Split jupyter components into own subpackage.
* Fri Sep  7 2018 toddrme2178@gmail.com
- Update to 1.4.0
  * Simplify js template
  * Display via single mime-bundle without side effects
* Thu Aug  2 2018 toddrme2178@gmail.com
- Update to 1.3.0
  * export vegaEmbed interface for use on other frontends
- Update to 1.2.0
  * Send same-origin cookies with Vega loader requests.
  * Upgrade deps
* Thu Jun  7 2018 toddrme2178@gmail.com
- Update to 1.1.1
  * BUG: update sanitize_dataframe and tests
  * Upgrade Vega-Embed and other dependencies
- Remove upstream-included update_sanitize_dataframe.patch
* Tue May 29 2018 toddrme2178@gmail.com
- Use || true syntax instead of exit 0
* Thu May 24 2018 toddrme2178@gmail.com
- Added update_sanitize_dataframe.patch
  Fixes compatibility with pandas 0.23
  See: https://github.com/vega/ipyvega/issues/87
  From: https://github.com/vega/ipyvega/pull/88
  Should be in next release
* Fri May 18 2018 jengelh@inai.de
- Avoid [[ ]] and test x==x bashisms.
* Thu May 17 2018 toddrme2178@gmail.com
- Initial version (1.0.1)
